# encoding: utf-8
"""
@author: luojunhui
"""
import requests

from applications.ai import tly_ai
from applications.ai import tencent_ai


class MatchArticles(object):
    """
    视频匹配文章流程
    流程
    1. 拿视频id，标题等信息匹配账号
    2. 账号匹配成功后，使用 AI Search 获取文章的生产资料
    3. 通过GPT4， 腾讯元宝等AI 优化文章
    4. 生成一篇文章，包含标题，文本，封面， 插图， 以及匹配到到小程序
    """

    def __init__(self, params):
        """
        :param params:
        """
        self.text_list = None
        self.images = None
        self.video_id = None
        self.title = None
        self.params = params

    def check_params(self):
        """
        params check
        """
        try:
            self.video_id = self.params['videoId']
            self.title = self.params['title']
            return None
        except AttributeError as e:
            response = {
                "code": 0,
                "error": "Params Error",
                "msg": "Params: {} is not correct".format(e)
            }
            return response

    def find_materials(self):
        """
        找到文章材料
        :return:
        {
    "query": "易中天对退休人的忠告，看了才没白活, 通过这个标题生成一遍文章",
    "follow_up_questions": null,
    "answer": "易中天对退休人的忠告主要强调退休后要活得舒坦、潇洒、有尊严。他建议不要期望子女回报，而是让他们自由发展。此外，易中天指出退休生活的关键是开心、舒坦、充实、快乐，要珍惜每一天的生活，学会宽容，不计较，以达到幸福的真谛。",
    "images": [
        "https://p6.itc.cn/q_70/images03/20220906/a8720c2a9d5a4140946aa2619f81a5a9.jpeg",
        "https://p4.itc.cn/q_70/images03/20220726/ea13877618a7469383a10e2342585b39.jpeg",
        "https://p6.itc.cn/q_70/images03/20221126/0165655914f7464f92e221a895e45457.png",
        "https://p9.itc.cn/q_70/images03/20221106/4c163c08a0a244b6bea689cc79c8a122.jpeg",
        "https://p0.ssl.img.360kuai.com/dmfd/__60/t019ae1d4c45a9ba51b.jpg"
    ],
    "results": [
        {
            "title": "易中天对退休人的忠告，看了才没白活!百万人收藏，受益无穷......",
            "url": "http://www.360doc.com/content/21/1218/09/42448055_1009233376.shtml",
            "content": "即将退休或者是已经退休的人，学着做到下面这几点，即使到了耄耋之年，仍能活得舒坦，活得潇洒，活得有尊严! 1、不求子女回报 我有一个女儿，我的教育方式就是\"不教育\"，我不期望她对我回报什么，我只期望我不要束缚了她。",
            "score": 0.90068,
            "raw_content": "发文章\n发文工具\n撰写\n网文摘手\n文档\n视频\n思维导图\n随笔\n相册\n原创同步助手\n其他工具\n图片转文字\n文件清理\nAI助手\n留言交流\n易中天对退休人的忠告，看了才没白活！百万人收藏，受益无穷......\n.\n易中天，\n中国知名作家、教育家，\n央视《百家讲坛》开坛论道的学者，\n是国内当之无愧的国学大师。\n易老师是一位充满智慧之人，\n其白话式的幽默，以人讲事，以事说人，\n往往能一语中的，给观众留下深刻的印象。\n博学而幽默的易老师，\n如今年过七十，退休生活过得有滋有味\n有人问他退休后该过怎样的生活？\n他的笑着做了一番回答，\n被无数人引为经典，\n整理成一篇文章与广大退休朋友分享。\n退休后的生活，总离不开两个词：开心，舒坦。\n我做教授这么多年，经历过不少的人情冷暖，也认识了很多的人。他们的遭遇或许不同，情感却大抵共通，大多数人的经验，总是值得借鉴与参考的。\n即将退休或者是已经退休的人，学着做到下面这几点，即使到了耄耋之年，仍能活得舒坦，活得潇洒，活得有尊严！\n1、不求子女回报\n我有一个女儿，我的教育方式就是“不教育”，我不期望她对我回报什么，我只期望我不要束缚了她。\n生养孩子，是我们的人生义务之一。对于儿女的付出，就不要指望他们会和你一样反馈回来。\n付出和回报不成正比，只有天下父母心。羊羔跪乳也是依旧在吸吮你的奶，它喂不成你。一定要省点奶养养自己。\n2、养老根本靠自己\n我今年73岁了，没有请保姆，养老完全靠自己。\n现在社会上多种养老方式，如老伴、新伴、子女、亲属、保姆、组织、社会等，分析的结果，根本的还是要靠自己。\n女人一定要有四样东西：\n扬在脸上的自信、长在心底的善良、融进血里的骨气、刻进命里的坚强。穿得起上千的大衣，也不嫌弃几十元的T恤，可以小鸟依人，也可以自力更生。有你，我可以坐拥天下，没你，我的世界依然伟大！送给天下所有的独立而善良，平凡而美丽的女人！如果你是一个女人，你的丈夫不优秀，那你必须成长，因为你没有依靠！如果你是一个女人，你的丈夫很优秀，你也必须成长，否则你无法跟上他前进的脚步！如果你是一个女人，你的孩子不优秀，那你必须成长，因为你要引领她的思想！如果你是一个女人，你的孩子很优秀，你也必须成长，因为你不能成为他的绊脚石！\n扬在脸上的自信、长在心底的善良、融进血里的骨气、刻进命里的坚强。\n穿得起上千的大衣，也不嫌弃几十元的T恤，可以小鸟依人，也可以自力更生。有你，我可以坐拥天下，没你，我的世界依然伟大！送给天下所有的独立而善良，平凡而美丽的女人！\n如果你是一个女人，\n你的丈夫不优秀，那你必须成长，因为你没有依靠！如果你是一个女人，你的丈夫很优秀，你也必须成长，否则你无法跟上他前进的脚步！\n如果你是一个女人，你必须成长，因为你要活得精彩，才不负此生！如果你是一个女人，你必须成长，女人赚钱不一定是责任，\n但一定是尊严！！！\n今年的小雪时间：2021年11月22日10点33分34秒，农历辛丑年十月十八号，星期一。小雪时节，气温开始逐渐降到0度以下，北方地区的雨水开始变成雪水，南方地区也开始进入一年中的湿冷季节。所以，很多人会在小雪前后出现受寒受湿又燥热所致的不适反应。此时最容易犯的养生忌讳是骤然大补。正确的保健方式“应顺从气候的变换，适当调整，以促进身体和大自然的合拍”，因此今天以后未来7天的保养关键主要是：外防湿冷，内防燥热，避寒就温的同时，不要过度燥补。。\n泡个脚，睡懒觉，通阻滞，化危机。人体项背、四肢的经络尤为丰富：背是人体督脉和足太阳膀胱经循行的主要部位；足的太阳膀胱经则主一身之表；所以足部、背部容易成为外邪入侵的地方，从而引发疾病，怎么重点保护呢？有两招：泡脚，通阻滞 注重背部保暖，就能有效防止寒邪损伤阳气。除了添衣加被，坚持每晚足浴也可以促进人体气血流通，达到促进末梢血液循环、暖身、防病保健的作用。建议每晚可用热水泡脚，或用一些中药煎煮后浸泡。比如花椒粉、生姜。老年人或糖尿病人也能泡脚，只要脚没有创口，水温保持在45度泡脚就没问题，泡20分钟上床睡觉，别搞到大汗淋漓。。\n睡懒觉，化危机 有心脑血管病或慢支等呼吸系统疾病的人应避免过早起床锻炼，以防小雪前后寒邪刺激，诱发新的疾病或加重原有疾病。冬天就要睡懒觉，像长寿的乌龟一样，睡在被子里，不要早起~睡到9点再起床出去锻炼，胜过一切补药。。\n精于心，简于形。拷问灵魂这是人的终极问题，简不仅是一种至美，也是一种能力、一种境界。看透了不说透，高境界；朦胧地看，心透 ；透非透、 知未知 ，故意不看透,才是透彻；知道世事看不透,就是透，透彻后的不透彻，明白后的不明白，难得糊涂是真境界。\n吃肉保暖+清火防燥保血管安全 由于小雪正值寒潮和强冷空气活动频繁时节，大家都会下意识把门窗关紧，室内开好暖气，再吃得热乎点。殊不知这样“全副武装”会让室内空气变得干燥，人体内热发散不畅而上火，干燥不光是造成口腔溃疡等小问题，最可怕的是：干燥这一点能让体内失水，血液变粘稠，让人晕晕乎乎缺氧、排便费力，从而引发心血管风险。建议大家在家里吃热菜时可多搭配些清火滋润的食物，如白萝卜、大白菜、菠菜、黑木耳、豆腐等。。\n白菜豆腐保健康，说的不是吃得清淡，而是搭配吃，美味得到的同时也兼顾健康，总不能为了长寿过和尚生活吧！另外，小雪时节还要多吃一些黑色的食物，如黑米、黑芝麻、黑木耳等，不仅可以补养肾气、抵抗寒冷，还能够润肺生津，具有很好的保健功能等。。\n小雪节气，9个必做的事 多运动 小雪过后进入了寒冷的冬季，此时天气异常寒冷，木枯草衰，万物凋零，阴雪纷纷，常会使人触景生情，抑郁不乐。其时节改变情绪，调摄身心的基本方法就是运动，散步、打太极都不错。要防寒 从这个节气开始，东北风刮得多了，由于气候虽冷却还没到严冬，很多人不太注意戴帽子、围巾，这样往往容易遭受风寒，因此，一定要注意防寒。。\n要防病 在冬天，老年人对寒冷刺激的适应性相对较差，因此也是心绞痛等心血管疾病的高发期，要注意保暖。每天清晨空腹喝一杯温开水，可以降低预防心脑血管疾病。多喝水 小雪节气多喝水也可防内热产生，缓解口干咽燥、便秘、皮肤干燥等不适。蜂蜜水可润燥解毒，白萝卜水能清热利尿，梨水可以润肺止咳。。\n多睡觉 小雪节气要增强体质、提高机体免疫力和抗寒能力。首先，要保证充足的睡眠。冬季应该早睡晚起，最好不要迟于22点休息。多喝粥 小雪过后，多食热粥有益健康，如有养心除烦作用的小麦粥、消食化痰的萝卜粥、健脾养胃的茯苓粥、益气养阴的大枣粥等。。\n大对现在，用最多的梦面对未来。\n吃黑豆 预防感冒是贯穿冬季养生的主题，而多吃黑色食物不仅能迅速补充热量、防感冒，还能滋补肝肾、清泻内火、保养肌肤。其中黑豆还有降低人体胆固醇的作用。晒太阳 多晒太阳不仅能“晒干”抑郁，还能帮助身体合成维生素D。冬日晒太阳最好选择红色的衣服，时间以30分钟左右为宜。喝鱼汤 药补不如食补，食补的方式有很多，而其中汤补可谓是“食补之首”。鱼汤含有全面而优质的蛋白质，还可缓解压力、睡眠不足等因素导致的皱纹。。\n最好的生活就是简单生活，一盏茶，一张桌，一处清幽，日子平淡，心无杂念。可是简单的生活却需要百般的努力，这样才会无忧无虑欣然享受生活。生活总的来说是完美的，不完美的是心态，不懂得欣赏的人，就会用挑剔把一切变得有残缺。简单做人，率性而为，把握分寸，随遇而安，坦然接受现实；简单做事，不惹事、不生事、不怕事，不悔、不怨、不惜自己所做的事。\n人生就是一场漫长对抗，有些人笑在开始，有些人却赢在最终。试着微笑，试着回眸，放松自己，不强求、不萎靡、不浮躁。简单生活，随心、随性、随缘，做最好的自己，知足、微笑、淡然，即使再苦再累，只要坚持往前走，属于自己的风景终会出现。\n生活容不容易，关键看你怎么活。处境在于心境，心境改变了，处境也会改变。你向生活要得越多，你就会变得越紧张、越复杂，生活也就越不容易。反之，你对生活要求的越少，就越容易满足，越容易快乐。江山明月，本无常主，得闲便是主人；大道至简，活在当下，知足便能常乐。\n悟入无怀之静境，一轮之心月独明，尽显心静之境界；心静自然从容洒脱，持心若水笑面人生，更现心静会在倾诉中流走，所有的紧张会在大笑中释放。像孩子一样，简单生活，快乐生活，保持心灵原生态，一切都是美好的。\n生命里总有一个故事，想讲述却难以开口，就这样在心底，渐渐谱成了曲。人就是这样，得不到的永远向往，失去了的，才会觉到珍贵。所谓的，得失、情缘、风景、驿站，都在时光的尘烟中，慢慢淡散。虽然，有些事情放下很难，但是，不属于自己的东西，终究会走远。\n人的一生，注定要经历很多。红尘路上，有朗朗的笑声，有委屈的泪水，懵懂的坚持着，有成功的自信，有失败的警醒，每一段经历注定珍贵。生命的丰盈缘于心的慈悲，生活的美好缘于拥有一颗平常心，生活简单让人轻松快乐，想法简单让人平\n守住自己的老伴、老本、老窝和老友，同时有自己的兴趣、追求，这样你的老年生活才会丰富多彩。\n3、趁早享受\n人生就这么几十年，好不容易来到这个世上，不借谁的、不欠谁的，挣多少就花多少，为啥要苦着自己、熬着自己呢？\n当你的牙好，腿好，身体也还行，趁着不聋不哑思维还清晰，品一下天下美味，看一看大好河山，四处走一走转一转，也不枉来世一遭。\n今天过去了，不会再有，我们应该珍惜每一天的生活。吃着了、喝着了，这一天过得就值，就不后悔！\n4、儿孙自有儿孙福\n儿女的生活不要去越俎代庖，儿孙自有儿孙福，他们是他们的一辈子，路是他们走，该撒手的必须撒手，让他们自己独立，你才能放下担子。\n不要劳心伤肺的为孩子的一些事情睡不着觉，就是不吃不睡，事情依然存在，不会有过不去的河，苍天饿不死天下麻雀，不要咸吃萝卜淡操心。\n5、发展一门兴趣\n我退休以后，喜欢写书法，这是我年轻时候就有的兴趣。\n趁年轻发展一门兴趣，给老了空巢做准备，等孩子离开家，也不至于一天到晚看着墙壁发呆。\n没有自己的精神寄托，那呆痴就会找你，这是必然的。\n6、心疼自己\n在心疼孩子的同时也心疼一下自己，孩子们再孝顺，感冒发烧你还得自己受，谁也替不了你。\n女人一定要有四样东西：\n扬在脸上的自信、长在心底的善良、融进血里的骨气、刻进命里的坚强。穿得起上千的大衣，也不嫌弃几十元的T恤，可以小鸟依人，也可以自力更生。有你，我可以坐拥天下，没你，我的世界依然伟大！送给天下所有的独立而善良，平凡而美丽的女人！如果你是一个女人，你的丈夫不优秀，那你必须成长，因为你没有依靠！如果你是一个女人，你的丈夫很优秀，你也必须成长，否则你无法跟上他前进的脚步！如果你是一个女人，你的孩子不优秀，那你必须成长，因为你要引领她的思想！如果你是一个女人，你的孩子很优秀，你也必须成长，因为你不能成为他的绊脚石！\n扬在脸上的自信、长在心底的善良、融进血里的骨气、刻进命里的坚强。\n穿得起上千的大衣，也不嫌弃几十元的T恤，可以小鸟依人，也可以自力更生。有你，我可以坐拥天下，没你，我的世界依然伟大！送给天下所有的独立而善良，平凡而美丽的女人！\n如果你是一个女人，\n你的丈夫不优秀，那你必须成长，因为你没有依靠！如果你是一个女人，你的丈夫很优秀，你也必须成长，否则你无法跟上他前进的脚步！\n如果你是一个女人，你必须成长，因为你要活得精彩，才不负此生！如果你是一个女人，你必须成长，女人赚钱不一定是责任，\n但一定是尊严！！！\n今年的小雪时间：2021年11月22日10点33分34秒，农历辛丑年十月十八号，星期一。小雪时节，气温开始逐渐降到0度以下，北方地区的雨水开始变成雪水，南方地区也开始进入一年中的湿冷季节。所以，很多人会在小雪前后出现受寒受湿又燥热所致的不适反应。此时最容易犯的养生忌讳是骤然大补。正确的保健方式“应顺从气候的变换，适当调整，以促进身体和大自然的合拍”，因此今天以后未来7天的保养关键主要是：外防湿冷，内防燥热，避寒就温的同时，不要过度燥补。。\n泡个脚，睡懒觉，通阻滞，化危机。人体项背、四肢的经络尤为丰富：背是人体督脉和足太阳膀胱经循行的主要部位；足的太阳膀胱经则主一身之表；所以足部、背部容易成为外邪入侵的地方，从而引发疾病，怎么重点保护呢？有两招：泡脚，通阻滞 注重背部保暖，就能有效防止寒邪损伤阳气。除了添衣加被，坚持每晚足浴也可以促进人体气血流通，达到促进末梢血液循环、暖身、防病保健的作用。建议每晚可用热水泡脚，或用一些中药煎煮后浸泡。比如花椒粉、生姜。老年人或糖尿病人也能泡脚，只要脚没有创口，水温保持在45度泡脚就没问题，泡20分钟上床睡觉，别搞到大汗淋漓。。\n睡懒觉，化危机 有心脑血管病或慢支等呼吸系统疾病的人应避免过早起床锻炼，以防小雪前后寒邪刺激，诱发新的疾病或加重原有疾病。冬天就要睡懒觉，像长寿的乌龟一样，睡在被子里，不要早起~睡到9点再起床出去锻炼，胜过一切补药。。\n精于心，简于形。拷问灵魂这是人的终极问题，简不仅是一种至美，也是一种能力、一种境界。看透了不说透，高境界；朦胧地看，心透 ；透非透、 知未知 ，故意不看透,才是透彻；知道世事看不透,就是透，透彻后的不透彻，明白后的不明白，难得糊涂是真境界。\n吃肉保暖+清火防燥保血管安全 由于小雪正值寒潮和强冷空气活动频繁时节，大家都会下意识把门窗关紧，室内开好暖气，再吃得热乎点。殊不知这样“全副武装”会让室内空气变得干燥，人体内热发散不畅而上火，干燥不光是造成口腔溃疡等小问题，最可怕的是：干燥这一点能让体内失水，血液变粘稠，让人晕晕乎乎缺氧、排便费力，从而引发心血管风险。建议大家在家里吃热菜时可多搭配些清火滋润的食物，如白萝卜、大白菜、菠菜、黑木耳、豆腐等。。\n白菜豆腐保健康，说的不是吃得清淡，而是搭配吃，美味得到的同时也兼顾健康，总不能为了长寿过和尚生活吧！另外，小雪时节还要多吃一些黑色的食物，如黑米、黑芝麻、黑木耳等，不仅可以补养肾气、抵抗寒冷，还能够润肺生津，具有很好的保健功能等。。\n小雪节气，9个必做的事 多运动 小雪过后进入了寒冷的冬季，此时天气异常寒冷，木枯草衰，万物凋零，阴雪纷纷，常会使人触景生情，抑郁不乐。其时节改变情绪，调摄身心的基本方法就是运动，散步、打太极都不错。要防寒 从这个节气开始，东北风刮得多了，由于气候虽冷却还没到严冬，很多人不太注意戴帽子、围巾，这样往往容易遭受风寒，因此，一定要注意防寒。。\n要防病 在冬天，老年人对寒冷刺激的适应性相对较差，因此也是心绞痛等心血管疾病的高发期，要注意保暖。每天清晨空腹喝一杯温开水，可以降低预防心脑血管疾病。多喝水 小雪节气多喝水也可防内热产生，缓解口干咽燥、便秘、皮肤干燥等不适。蜂蜜水可润燥解毒，白萝卜水能清热利尿，梨水可以润肺止咳。。\n多睡觉 小雪节气要增强体质、提高机体免疫力和抗寒能力。首先，要保证充足的睡眠。冬季应该早睡晚起，最好不要迟于22点休息。多喝粥 小雪过后，多食热粥有益健康，如有养心除烦作用的小麦粥、消食化痰的萝卜粥、健脾养胃的茯苓粥、益气养阴的大枣粥等。。\n大对现在，用最多的梦面对未来。\n吃黑豆 预防感冒是贯穿冬季养生的主题，而多吃黑色食物不仅能迅速补充热量、防感冒，还能滋补肝肾、清泻内火、保养肌肤。其中黑豆还有降低人体胆固醇的作用。晒太阳 多晒太阳不仅能“晒干”抑郁，还能帮助身体合成维生素D。冬日晒太阳最好选择红色的衣服，时间以30分钟左右为宜。喝鱼汤 药补不如食补，食补的方式有很多，而其中汤补可谓是“食补之首”。鱼汤含有全面而优质的蛋白质，还可缓解压力、睡眠不足等因素导致的皱纹。。\n最好的生活就是简单生活，一盏茶，一张桌，一处清幽，日子平淡，心无杂念。可是简单的生活却需要百般的努力，这样才会无忧无虑欣然享受生活。生活总的来说是完美的，不完美的是心态，不懂得欣赏的人，就会用挑剔把一切变得有残缺。简单做人，率性而为，把握分寸，随遇而安，坦然接受现实；简单做事，不惹事、不生事、不怕事，不悔、不怨、不惜自己所做的事。\n人生就是一场漫长对抗，有些人笑在开始，有些人却赢在最终。试着微笑，试着回眸，放松自己，不强求、不萎靡、不浮躁。简单生活，随心、随性、随缘，做最好的自己，知足、微笑、淡然，即使再苦再累，只要坚持往前走，属于自己的风景终会出现。\n生活容不容易，关键看你怎么活。处境在于心境，心境改变了，处境也会改变。你向生活要得越多，你就会变得越紧张、越复杂，生活也就越不容易。反之，你对生活要求的越少，就越容易满足，越容易快乐。江山明月，本无常主，得闲便是主人；大道至简，活在当下，知足便能常乐。\n悟入无怀之静境，一轮之心月独明，尽显心静之境界；心静自然从容洒脱，持心若水笑面人生，更现心静会在倾诉中流走，所有的紧张会在大笑中释放。像孩子一样，简单生活，快乐生活，保持心灵原生态，一切都是美好的。\n生命里总有一个故事，想讲述却难以开口，就这样在心底，渐渐谱成了曲。人就是这样，得不到的永远向往，失去了的，才会觉到珍贵。所谓的，得失、情缘、风景、驿站，都在时光的尘烟中，慢慢淡散。虽然，有些事情放下很难，但是，不属于自己的东西，终究会走远。\n人的一生，注定要经历很多。红尘路上，有朗朗的笑声，有委屈的泪水，懵懂的坚持着，有成功的自信，有失败的警醒，每一段经历注定珍贵。生命的丰盈缘于心的慈悲，生活的美好缘于拥有一颗平常心，生活简单让人轻松快乐，想法简单让人平\n你觉得孩子是你身上掉下来的肉，但他们决不会觉得你是他们身上掉下来的肉，那是两个概念。\n自己年轻时没赶上好时候，生活困难，吃不起、穿不起，可是现在有了条件了，再舍不得吃，舍不得穿，就太糊涂了。\n7、舍得给自己花钱\n该给自己花一块的，决不去花八毛。你后半生的消费是有限的，没有必要对自己吝啬。\n再省也不会有人给你立牌坊，只会苦了自己。\n8、不攀比，不计较\n退休后，不去攀比，不去比较，大半辈子都过去了，什么都是浮云，你的存在就是最好，伸长了你的腿脚也占不了一两米地方。\n知足而乐就是当下，减少和压制自己的欲望。步入老年，看山是山，看水是水，没有什么事情特别稀奇。\n9、释放自己，享受喜悦\n找上一两个挚友，放松自己，该说就说，该唱就唱，释放自己的一些郁闷，共同享受自己的喜悦，老来疯上一阵有何不可？\n没有人能够约束住你的精神，何乐而不为？年轻时的矜持可以一扫而光，只求精神的极大放松，自然、放松就是你身体正常运转的不二法宝。\n10、不要硬撑\n就算是一头驴，拉磨时间长了也得歇歇脚。到了一定年纪，任何事情都不硬着来。\n绳子断的时候就是在最细的地方出问题，如果觉得难受，不是休息就是找医生，决不坚持。\n11、随遇而安\n人生的路走过去了一大半，什么事情也是司空见惯，真理的概念有时候不见得是人多人少来认定的，没有必要去争上争下。\n该磨的棱角已经磨去，已经到了不好抓住你的时候，再让人抓住你的把柄，那你是真傻了。\n人老了，不是圆滑，是释然，不是老谋深算，是老成，是随遇而安。\n12、吃补药不如一日三餐\n不要相信那些养生的鬼把戏，吃什么补药都不如一日三餐安排妥当，酸辣稀稠自己找自己的感觉，不能让别人说了算。\n动物的任何自然规律你都存在，不是吃把药就能够长生不老，把钱花到不必要的地方去，还不如多吃点美味佳肴，落个嘴福。\n13、坚持锻炼\n任何锻炼都是循序渐进的，老了以后，锻炼就是相对消遣的事情，带有一定的娱乐性质，要适当消耗。\n不要认为你还可以和年轻人一比高下，最后趴下的是你，那就得不偿失。\n14、尽量不生气\n气是一只虎，抓肝又伤肚，只当它是屁，放了才舒服！\n生气有“四害”：血压变高，血脂变稠，血色变紫，血管变细。还可能引发脑塞，心肌梗死。所以，千万别生气。\n不要把有些事情放在心上，老了要有点滚刀肉的精神，不怕说，不怕议，不怕背后嚼舌头。任由他们去吧，我依然是我，开心快乐过！\n15、有自己的生活信条\n人生百年，不过是一个过程，好坏冷暖自知，想要潇洒就必须有自己的生活信条。\n不为他人所动，轻松自然地活着，就是你生命精彩的路径。\n16、快乐永远是第一\n一辈子很短，快乐就好。最人最重要的就是开心，学会宽容，不去计较。忘记名利，忘记恩怨，忘记烦恼。与人为善，不图回报，快乐来找。\n保持年轻心态，前半辈子努力换来后半辈子幸福生活。好好享受，别浪费大好时光。\n正所谓：过一天，少一天；过一天，乐一天；乐一天，赚一天！\n退休后过这样的生活，人生才算没白活。\n不管你正当年轻，\n还是已过中年，\n做你应该做的事。\n如果你的生活以金钱为中心，你会活的很苦；\n如果你的生活以儿女为中心，你会活的很累；\n如果你的生活以爱情为中心，你会活的很伤；\n如果你的生活以攀比为中心，你会活的很苦闷；\n如果你的生活以宽容为中心，你会活的很幸福；\n如果你的生活以知足为中心，你会活的很快乐；\n如果你的生活以感恩为中心，你会活的很善良；\n做人：对上恭敬、对下不傲，是为礼；\n做事：大不糊涂、小不计较，是为智；\n对利：能拿六分，只拿四分，是为义；\n恪律：守身如莲，香远益清，是为廉；\n对人：表里如一，真诚以待，是为信；\n修心：优为聚灵，敬天爱人，是为仁。\n在没钱的时候把勤舍得出去，钱就来了。一一这叫天道酬勤。在有钱的时候把钱舍得出去，人就来了。一一这叫财散人聚。当有人的时候把爱舍弃出去，事业就来了。一一这叫博爱领众。当事业成功后把智慧舍得出去，喜悦就来了。一一这叫德行天下。没有舍、就没有得！切记……世界是圆的，你怎么对别人，别人就怎么对你…\n在没钱的时候\n把勤舍得出去，钱就来了。\n一一这叫天道酬勤。\n在有钱的时候\n把钱舍得出去，人就来了。\n一一这叫财散人聚。\n当有人的时候\n把爱舍弃出去，事业就来了。\n一一这叫博爱领众。\n当事业成功后\n把智慧舍得出去，喜悦就来了。\n一一这叫德行天下。\n没有舍、就没有得！\n切记……世界是圆的，\n你怎么对别人，别人就怎么对你…\n易中天老师的退休建议，说得太好了！值得每个中老年人都看看，发到你的圈子里，朋友看了会感激你的！\n易中天老师的退休建议，说得太好了！值得每个中老年人都看看，发到你的圈子里，朋友看了会感激你的！\n传播正能量，拒绝冷漠！\n传播正能量，拒绝冷漠！\n不要私存，放到圈子里，让更多的人看到\n不要私存，放到圈子里，让更多的人看到\n阅读后顺便点亮【在看】，如果觉得文章不错，请把它传播出去，传递正能量，谢谢！\n来自：\n昵称42448055\n>\n《待分类》\n0条评论\n发表\n请遵守用户 评论公约\n60岁以后这样活，才是最精彩、最快乐的退休人生！\n60岁以后这样活，才是最精彩、最快乐的退休人生！一辈子，30000天。刚一看到这个数字，人生，真的只有短短三万天吗？突然觉得，人生真的...\n退休后的生活应该是怎样的？\n退休后的生活应该是怎样的？人这一生过的真快，忙忙碌碌，不知不觉已到了退休的年龄，我常常在思考，退休后的生活到底是什么样的呢？是退休后继续上岗操心儿女带孙子呢？还是开开心心过好自己的余生呢...\n朱大鹏配景画1.22（带着幸福来见你/山水组合）\n朱大鹏配景画1.22（带着幸福来见你/山水组合）\n打开美篇APP查看高清图片\n打开美篇APP查看高清图片。打开美篇APP查看高清图片\n...\n最佳的退休状态是怎样的？\n最佳的退休状态是怎样的？3.有夫妻生活，退休了也老当益壮。4.有自己的老窝，过自己的生活，自由自在无人管束。10.对晚年的生活环境很满意，周围都是熟悉的人。18.开始对自己真正的好，明白了要善待自...\n【转载】一个好儿媳三代好儿孙\n【转载】一个好儿媳三代好儿孙。一个好儿媳，三代好儿孙。女人的水平或者在家庭生活中、子女教育上成功与否与学历的关系不是最直接的，有些女人她受过高等教育，有学识，但是她的道德水准与她是学识水...\n新出的！一首唱给退休人的歌，太精辟了！中老年人都看看！\n一首唱给退休人的歌，太精辟了！中老年人都看看！新出的《快乐老年歌》，哪位高人编的？太绝了，值得所有中老年人传阅！《快 乐 老 年 ...\n2017最新退休歌，送给中老年朋友们！\n2017最新退休歌，送给中老年朋友们！快 乐 歌人生易老天难老人生容易生烦恼耳聋眼花身乏力东西放下找不着。看着儿孙都长大咱旳功劳真不...\n退休老人，学会拒绝以下几件事，才能活得轻松\n退休老人，学会拒绝以下几件事，才能活得轻松。儿女的事，不要大包大揽。费孝通说：“在父母的眼中，孩子是自我的一部分，子女是他理想...\n这 8 件事，在变老之前要做到，越早越好！\n这 8 件事，在变老之前要做到，越早越好！在退休前做到这8件事，余生才能轻松自在。第一件事：存养老钱。每个人都该为养老做准备，存养...\n微信扫码，在手机上查看选中内容\n微信扫码，在手机上查看选中内容"
        }
    ]
}

        """
        materials_dict = tly_ai(
            prompt=self.title
        )
        print(materials_dict)
        self.images = materials_dict['images']
        self.text_list = materials_dict['results']

    def generate_text(self):
        """
        生成文本
        :return:
        """
        text_list = [i['raw_content'] for i in self.text_list]
        generate_prompt = f"""
        总结这些文本材料，写一篇文章，字数不少于1000字：
        {text_list}
        """
        response_text = tencent_ai(prompt=generate_prompt)
        return {"text": response_text}

    def get_basic_video_info(self):
        """
        获取视频信息
        :return:
        """
        url = "http://localhost:8888/singleVideo"
        body = {
            "videoId": self.video_id
        }
        headers = {
            "Content-Type": "application/json"
        }
        response = requests.post(url=url, json=body, headers=headers)
        return response.json()

    def deal(self):
        """
        Deal Function
        :return:
        """
        params_error = self.check_params()
        if params_error:
            return params_error
        else:
            # 把数据插入到mysql中
            print("校验通过，开始处理")
            self.find_materials()
            text = self.generate_text()
            return {
                "title": self.title,
                "cover": self.images[0],
                "content": text,
                "images": self.images,
                "videos": [
                    self.get_basic_video_info()
                ]
            }
